'use strict';

const { uuid } = require('uuidv4');
const dotenv = require('dotenv');
const fs = require('fs');
const path = require('path');
const Sequelize = require('sequelize');

const env = process.env.REACT_APP_ENV;
dotenv.config({ path: `.env.${env}` }); 

const basename = path.basename(__filename);
const config = {
  dialect: 'mysql',
  host: process.env.DB_HOST, 
  port: process.env.DB_PORT, 
  username: process.env.DB_USERNAME, 
  password: process.env.DB_PASSWORD, 
  database: process.env.DB_DATABASE, 
  logging: console.log,
  timestamps: false,
  // dialectOptions: { socketPath: process.env.DB_HOST },
  seederStorage: 'sequelize',
};

const db = {};
let sequelize;

sequelize = new Sequelize(
  config.database,
  config.username,
  config.password,
  config,
);

fs.readdirSync(__dirname)
  .filter((file) => {
    return (
      file.indexOf('.') !== 0 && file !== basename && file.slice(-3) === '.js'
    );
  })
  .forEach((file) => {
    const model = require(path.join(__dirname, file))(
      sequelize,
      Sequelize.DataTypes,
    );
    db[model.name] = model;
  });

Object.keys(db).forEach((modelName) => {
  if (db[modelName].associate) {
    db[modelName].associate(db);
  }
});

db.sequelize = sequelize;
db.Sequelize = Sequelize;

db.puja_samagri_mappings.beforeCreate((model, _) => {
  return (model.id = uuid());
});

db.puja_history.beforeCreate((user, _) => {
  return (user.id = uuid());
});

db.samagri.beforeCreate((samagri, _) => {
  return (samagri.id = uuid());
});

db.puja_model_procedure_mappings.beforeCreate((procedure, _) => {
  return (procedure.id = uuid());
});

module.exports = db;
