const config = require('../../config');
const providers = config.providers;
const crypto = require('crypto');
const bcrypt = require('bcrypt');
const moment = require('moment');

module.exports = function (sequelize, DataTypes) {
  const puja_models = sequelize.define(
    'puja_models',
    {
      id: {
        type: DataTypes.INTEGER,
        primaryKey: true,
        autoIncrement: true,
      },

      puja_id: {
        type: DataTypes.INTEGER,
      },

      duration_hrs: {
        type: DataTypes.INTEGER,
      },

      pujari_cost: {
        type: DataTypes.INTEGER,
      },

      no_of_pujaris: {
        type: DataTypes.INTEGER,
      },

      model_selling_price: {
        type: DataTypes.INTEGER,
      },

      advance_amount: {
        type: DataTypes.INTEGER,
      },

      is_popular_model: {
        type: DataTypes.INTEGER,
      },

      createdAt: {
        type: DataTypes.DATE,
      },

      createdById: {
        type: DataTypes.UUID,
      },

      deletedAt: {
        type: DataTypes.DATE,
      },

      updatedAt: {
        type: DataTypes.DATE,
      },

      updatedById: {
        type: DataTypes.UUID,
      },

      indicative_cost_price: {
        type: DataTypes.INTEGER,
      },

      name: {
        type: DataTypes.TEXT,
      },

      samagri_cost: {
        type: DataTypes.INTEGER,
      },

      service_fee: {
        type: DataTypes.INTEGER,
      },

      importHash: {
        type: DataTypes.STRING(255),
        allowNull: true,
        unique: true,
      },
    },
    {
      timestamps: true,
      paranoid: true,
      freezeTableName: true,
    },
  );

  puja_models.associate = (db) => {
    db.puja_models.belongsTo(db.users, {
      as: 'createdBy',
    });

    db.puja_models.belongsTo(db.users, {
      as: 'updatedBy',
    });

    db.puja_models.hasMany(db.puja_model_procedure_mappings, {
      foreignKey: 'model_id',
    });
  };

  return puja_models;
};
