const config = require('../../config');
const providers = config.providers;
const crypto = require('crypto');
const bcrypt = require('bcrypt');
const moment = require('moment');
const pujaHistory = require('./puja_history');

module.exports = function (sequelize, DataTypes) {
  const pujas = sequelize.define(
    'pujas',
    {
      id: {
        type: DataTypes.INTEGER,
        //defaultValue: DataTypes.UUIDV4,
        primaryKey: true,
        autoIncrement: true,
      },

      name: {
        type: DataTypes.TEXT,
      },
      
      url_name: {
        type: DataTypes.TEXT,
      },

      description: {
        type: DataTypes.TEXT,
      },

      language: {
        type: DataTypes.ENUM,

        values: ['Telugu', 'Other'],
      },

      duration_hrs: {
        type: DataTypes.INTEGER,
      },

      mode1: {
        type: DataTypes.ENUM,
        values: ['remote', 'at_my_home', 'near_my_home', 'on_behalf'],
      },

      mode2: {
        type: DataTypes.ENUM,
        values: ['remote', 'at_my_home', 'near_my_home', 'on_behalf'],
      },

      mode3: {
        type: DataTypes.ENUM,
        values: ['remote', 'at_my_home', 'near_my_home', 'on_behalf'],
      },

      mode4: {
        type: DataTypes.ENUM,
        values: ['remote', 'at_my_home', 'near_my_home', 'on_behalf'],
      },

      videos: {
        type: DataTypes.TEXT,
      },

      images: {
        type: DataTypes.TEXT,
      },

      importHash: {
        type: DataTypes.STRING(255),
        allowNull: true,
        unique: true,
      },
    },
    {
      timestamps: true,
      paranoid: true,
      freezeTableName: true,
    },
  );

  pujas.associate = (db) => {
    db.pujas.belongsTo(db.users, {
      as: 'createdBy',
    });

    db.pujas.belongsTo(db.users, {
      as: 'updatedBy',
    });

    db.pujas.hasMany(db.puja_history, {
      foreignKey: 'puja_id',
    });

    db.pujas.hasMany(db.puja_samagri_mappings, {
      foreignKey: 'puja_id',
    });
  };

  return pujas;
};
