const db = require('../db/models');
const Booking_samagri_mappingsDBApi = require('../db/api/booking_samagri_mappings');
const ValidationError = require('./notifications/errors/validation');


module.exports = class Booking_samagri_mappingsService {
  static async create(data, currentUser) {
    const transaction = await db.sequelize.transaction();
    try {
      const data = await Booking_samagri_mappingsDBApi.create(data, {
        currentUser,
        transaction,
      });

      await transaction.commit();

      return data;
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }
  static async update(data, id, currentUser) {
    const transaction = await db.sequelize.transaction();
    try {
      let booking_samagri_mappings = await Booking_samagri_mappingsDBApi.findBy(
        { id },
        { transaction },
      );

      if (!booking_samagri_mappings) {
        throw new ValidationError('booking_samagri_mappingsNotFound');
      }

      await Booking_samagri_mappingsDBApi.update(id, data, {
        currentUser,
        transaction,
      });

      await transaction.commit();
      return booking_samagri_mappings;
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async remove(id, currentUser) {
    const transaction = await db.sequelize.transaction();

    try {
      if (currentUser.role !== 'admin') {
        throw new ValidationError('errors.forbidden.message');
      }

      await Booking_samagri_mappingsDBApi.remove(id, {
        currentUser,
        transaction,
      });

      await transaction.commit();

      return { message: 'success' };
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async bookingSamagri(id, currentUser) {

    try {
      // if (currentUser.role !== 'admin') {
      //   throw new ValidationError('errors.forbidden.message');
      // }

      // const data = await  db.sequelize.query(`SELECT mappings.id as id, mappings.booking_id as booking_id, procedures.language as language, procedures.title as title, procedures.description as description,
      // procedures.special_notes as special_notes FROM karishyebackend.booking_procedure_mappings as mappings join 
      // karishyebackend.puja_procedures as procedures on procedures.id = mappings.procedure_id 
      // where booking_id=${id}`);

      // let include = [db.samagri, { model: db.samagri, required: true }];
      let include = [db.samagri];

      // const booking = await db.bookings.findOne({ where: { id: id } });

      // const pujaId = booking?.puja_id;

      // const samagriData = await db.puja_samagri_mappings.findAll({ where: { puja_id: pujaId } });
      const { rows, count } = await db.booking_samagri_mappings.findAndCountAll({
        where: { booking_id: id },
        include: include,
      });


      const filterData = rows.filter(item => item.samagri != null);



      // const transformeddata = rows.map(objA => {
      //   const matchingObjB = samagriData.find(objB => objB.samagri_id === objA.samagri_id);
      //   if (matchingObjB) {
      //     return { ...objA.dataValues };
      //   } else {
      //     return { ...objA.dataValues };
      //   }
      // });
      return { rows: filterData, count: filterData.length };

    } catch (error) {

      throw error;
    }
  }
};
